@@ -1,4 +1,4 @@
-__version__ = '2.0.0'
+__version__ = "2.2.3"
 
 import fullmetalalchemy.create as create
 import fullmetalalchemy.delete as delete
@@ -9,12 +9,15 @@ import fullmetalalchemy.records as records
 import fullmetalalchemy.select as select
 import fullmetalalchemy.type_convert as type_convert
 import fullmetalalchemy.update as update
+from fullmetalalchemy.batch import BatchProcessor, BatchResult
 from fullmetalalchemy.create import create_engine
 from fullmetalalchemy.features import get_engine_table, get_table, get_table_names
 from fullmetalalchemy.sessiontable import SessionTable
 from fullmetalalchemy.table import Table
 
 __all__ = [
+    "BatchProcessor",
+    "BatchResult",
     "SessionTable",
     "Table",
     "create",
