@@ -40,11 +40,9 @@ class SessionTable(BaseTable):
     --------
     fullmetalalchemy.table.Table
     """
+
     def __init__(
-        self,
-        name: str,
-        engine: _sa_engine.Engine | _sa_session.Session,
-        schema: str | None = None
+        self, name: str, engine: _sa_engine.Engine | _sa_session.Session, schema: str | None = None
     ) -> None:
         super().__init__(name, engine, schema)
         if type(engine) is _sa_session.Session:
@@ -52,7 +50,7 @@ class SessionTable(BaseTable):
         elif type(engine) is _sa_engine.Engine:
             self.session = _features.get_session(engine)
         else:
-            raise TypeError('engine must be SqlAlchemy Engine or Session')
+            raise TypeError("engine must be SqlAlchemy Engine or Session")
 
     def __enter__(self) -> SessionTable:
         return self
@@ -61,7 +59,7 @@ class SessionTable(BaseTable):
         self,
         exc_type: _t.Optional[_t.Type[BaseException]],
         exc_value: _t.Optional[BaseException],
-        traceback: _t.Optional[_t.Any]
+        traceback: _t.Optional[_t.Any],
     ) -> None:
         if exc_type and exc_value:
             self.rollback()
@@ -71,8 +69,8 @@ class SessionTable(BaseTable):
 
     def __repr__(self) -> str:
         return (
-            f'SessionTable(name={self.name}, columns={self.column_names}, '
-            f'pks={self.primary_key_names}, types={self.column_types})'
+            f"SessionTable(name={self.name}, columns={self.column_names}, "
+            f"pks={self.primary_key_names}, types={self.column_types})"
         )
 
     def commit(self) -> SessionTable:
@@ -85,54 +83,34 @@ class SessionTable(BaseTable):
         self.session.rollback()
         return SessionTable(self.name, self.engine, self.schema)
 
-    def delete_records(
-        self,
-        column_name: str,
-        values: _t.Sequence[_t.Any]
-    ) -> None:
+    def delete_records(self, column_name: str, values: _t.Sequence[_t.Any]) -> None:
         _delete.delete_records_session(self.sa_table, column_name, values, self.session)
 
-    def delete_records_by_values(
-        self,
-        records: _t.List[_t.Dict[str, _t.Any]]
-    ) -> None:
+    def delete_records_by_values(self, records: _t.List[_t.Dict[str, _t.Any]]) -> None:
         _delete.delete_records_by_values_session(self.sa_table, records, self.session)
 
     def delete_all_records(self) -> None:
         _delete.delete_all_records_session(self.sa_table, self.session)
 
-    def insert_from_table(
-        self,
-        sa_table: _sa.Table
-    ) -> None:
+    def insert_from_table(self, sa_table: _sa.Table) -> None:
         _insert.insert_from_table_session(self.sa_table, sa_table, self.session)
 
-    def insert_records(
-        self,
-        records: _t.Sequence[_types.Record]
-    ) -> None:
+    def insert_records(self, records: _t.Sequence[_types.Record]) -> None:
         _insert.insert_records_session(self.sa_table, records, self.session)
 
     def update_matching_records(
-        self,
-        records: _t.Sequence[_types.Record],
-        match_column_names: _t.Sequence[str]
+        self, records: _t.Sequence[_types.Record], match_column_names: _t.Sequence[str]
     ) -> None:
         _update.update_matching_records_session(
-            self.sa_table, records, match_column_names, self.session)
+            self.sa_table, records, match_column_names, self.session
+        )
 
     def update_records(
         self,
         records: _t.Sequence[_types.Record],
         match_column_names: _t.Sequence[str] | None = None,
     ) -> None:
-        _update.update_records_session(
-            self.sa_table, records, self.session, match_column_names)
+        _update.update_records_session(self.sa_table, records, self.session, match_column_names)
 
-    def set_column_values(
-        self,
-        column_name: str,
-        value: _t.Any
-    ) -> None:
-        _update.set_column_values_session(
-            self.sa_table, column_name, value, self.session)
+    def set_column_values(self, column_name: str, value: _t.Any) -> None:
+        _update.set_column_values_session(self.sa_table, column_name, value, self.session)
